[Scipy-svn] r2186 - trunk/Lib/interpolate

scipy-svn at scipy.org scipy-svn at scipy.org
Sat Sep 2 18:09:26 EDT 2006


Author: stefan
Date: 2006-09-02 17:09:19 -0500 (Sat, 02 Sep 2006)
New Revision: 2186

Modified:
   trunk/Lib/interpolate/fitpack.py
Log:
Fix previous patch to use int32 instead of intc.


Modified: trunk/Lib/interpolate/fitpack.py
===================================================================
--- trunk/Lib/interpolate/fitpack.py	2006-08-30 15:18:55 UTC (rev 2185)
+++ trunk/Lib/interpolate/fitpack.py	2006-09-02 22:09:19 UTC (rev 2186)
@@ -33,7 +33,7 @@
 __version__ = "$Revision$"[10:-1]
 import _fitpack
 from numpy import atleast_1d, array, ones, zeros, sqrt, ravel, transpose, \
      dot, sin, cos, pi, arange, empty, intc
 myasarray = atleast_1d
 
 # Try to replace _fitpack interface with
@@ -101,7 +101,7 @@
     An error occured""",TypeError]}
 
 _parcur_cache = {'t': array([],float), 'wrk': array([],float),
-                 'iwrk':array([],intc), 'u': array([],float),'ub':0,'ue':1}
+                 'iwrk':array([],int32), 'u': array([],float),'ub':0,'ue':1}
 
 def splprep(x,w=None,u=None,ub=None,ue=None,k=3,task=0,s=None,t=None,
             full_output=0,nest=None,per=0,quiet=1):
@@ -169,7 +169,7 @@
     """
     if task<=0:
         _parcur_cache = {'t': array([],float), 'wrk': array([],float),
-                         'iwrk':array([],intc),'u': array([],float),
+                         'iwrk':array([],int32),'u': array([],float),
                          'ub':0,'ue':1}
     x=myasarray(x)
     idim,m=x.shape
@@ -245,7 +245,7 @@
         return tcku
 
 _curfit_cache = {'t': array([],float), 'wrk': array([],float),
-                 'iwrk':array([],intc)}
+                 'iwrk':array([],int32)}
 def splrep(x,y,w=None,xb=None,xe=None,k=3,task=0,s=1e-3,t=None,
            full_output=0,per=0,quiet=1):
     """Find the B-spline representation of 1-D curve.
@@ -353,7 +353,7 @@
         _curfit_cache['t'] = t
     if task <= 0:
         _curfit_cache['wrk'] = empty((m*(k+1)+nest*(7+3*k),),float)
-        _curfit_cache['iwrk'] = empty((nest,),intc)
+        _curfit_cache['iwrk'] = empty((nest,),int32)
     try:
         t=_curfit_cache['t']
         wrk=_curfit_cache['wrk']
@@ -532,7 +532,7 @@
 #           full_output=0,nest=None,per=0,quiet=1):
 
 _surfit_cache = {'tx': array([],float),'ty': array([],float),
-                 'wrk': array([],float), 'iwrk':array([],intc)}
+                 'wrk': array([],float), 'iwrk':array([],int32)}
 def bisplrep(x,y,z,w=None,xb=None,xe=None,yb=None,ye=None,kx=3,ky=3,task=0,
              s=None,eps=1e-16,tx=None,ty=None,full_output=0,
              nxest=None,nyest=None,quiet=1):
@@ -33,7 +33,7 @@
 import _fitpack
 from numpy import atleast_1d, array, ones, zeros, sqrt, ravel, transpose, \
-     dot, sin, cos, pi, arange, empty, intc
+     dot, sin, cos, pi, arange, empty, int32
 myasarray = atleast_1d
 




More information about the Scipy-svn mailing list